==> zeppelin-0.10.1.tgz: zeppelin-0.10.1/zeppelin-interpreter-integration/src/test/java/org/apache/zeppelin/integration/SparkIntegrationTest32.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.zeppelin.integration;

import org.apache.zeppelin.interpreter.InterpreterSetting;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;

import java.util.Arrays;
import java.util.List;

@RunWith(value = Parameterized.class)
public class SparkIntegrationTest32 extends SparkIntegrationTest {

  public SparkIntegrationTest32(String sparkVersion, String hadoopVersion) {
    super(sparkVersion, hadoopVersion);
  }

  @Parameterized.Parameters
  public static List<Object[]> data() {
    return Arrays.asList(new Object[][]{
        {"3.2.0", "2.7"},
        // TODO(zjffdu) Run integration tests under profile hadoop3
        // {"3.2.0", "3.2"}
    });
  }

  @Override
  protected void setUpSparkInterpreterSetting(InterpreterSetting interpreterSetting) {
    // spark3 doesn't support yarn-client and yarn-cluster anymore, use
    // spark.master and spark.submit.deployMode instead
    String sparkMaster = interpreterSetting.getJavaProperties().getProperty("spark.master");
    if (sparkMaster.equals("yarn-client")) {
      interpreterSetting.setProperty("spark.master", "yarn");
      interpreterSetting.setProperty("spark.submit.deployMode", "client");
    } else if (sparkMaster.equals("yarn-cluster")){
      interpreterSetting.setProperty("spark.master", "yarn");
      interpreterSetting.setProperty("spark.submit.deployMode", "cluster");
    } else if (sparkMaster.startsWith("local")) {
      interpreterSetting.setProperty("spark.submit.deployMode", "client");
    }
  }
}

==> zeppelin-0.11.2.tgz: zeppelin-0.11.2/zeppelin-interpreter-integration/src/test/java/org/apache/zeppelin/integration/SparkIntegrationTest32.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.zeppelin.integration;

import org.apache.zeppelin.interpreter.InterpreterSetting;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import java.io.IOException;

public class SparkIntegrationTest32  {

  @Nested
  @DisplayName("Hadoop2")
  public class Hadoop2 extends SparkIntegrationTest {

    @BeforeEach
    public void downloadSpark() throws IOException {
      prepareSpark("3.2.0", "2.7");
    }
  }

  @Nested
  @DisplayName("Hadoop3")
  public class Hadoop3 extends SparkIntegrationTest {

    @BeforeEach
    public void downloadSpark() throws IOException {
      prepareSpark("3.2.0", "3.2");
    }
  }
}
